
# Type: has evidence


connects an association to an instance of supporting evidence

URI: [biolink:has_evidence](https://w3id.org/biolink/vocab/has_evidence)


## Domain and Range

[Association](Association.md) ->  <sub>OPT</sub> [EvidenceType](EvidenceType.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [Association](Association.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002558 |

